@@ -2,61 +2,8 @@
 #' @docType class
 #' @export
 #' @keywords ocs manager sharing api
-#' @return Object of \code{\link{R6Class}} for modelling an ocsManager for the Sharing API
-#' @format \code{\link{R6Class}} object.
-#' @section General Methods (inherited from 'ocsManager'):
-#' \describe{
-#'  \item{\code{new(url, user, pwd, logger, keyring_backend)}}{
-#'    This method is used to instantiate an ocsApiSharingManager. The user/pwd are
-#'    mandatory in order to connect to 'ocs'. 
-#'    
-#'    The logger can be either NULL, "INFO" (with minimum logs), or "DEBUG" 
-#'    (for complete curl http calls logs).
-#'    
-#'    The \code{keyring_backend} can be set to use a different backend for storing 
-#'    the user password with \pkg{keyring} (Default value is 'env').
-#'  }
-#'  \item{\code{connect()}}{
-#'    A method to connect to 'ocs' and set version/capabilities
-#'  }
-#'  \item{\code{getVersion()}}{
-#'    Get the 'ocs' server version
-#'  }
-#'  \item{\code{getCapabilities()}}{
-#'    Get the 'ocs' server capabilities
-#'  }
-#' }
-#' 
-#' @section 'OCS' Share API methods:
-#' \describe{
-#'  \item{\code{getShares(path, reshares, shared_with_me, state, subfiles, pretty)}}{
-#'    Get list of shares as \code{list}. To return as \code{data.frame}, set 
-#'    \code{pretty = TRUE}. The method accepts additional parameters. 
-#'  }
-#'  \item{\code{createShare(path, name, shareType, shareWith, publicUpload, password, 
-#'  permissions = NULL, expireDate = NULL)}}{
-#'    Creates a share for the path (file or folder), given a name. The \code{shareType} should be among
-#'    values 'user','group','publiclink' or 'federated'.The \code{shareWith} is required for \code{shareType} 
-#'    'user' and 'group' and corresponds to the username or groupname. The \code{permissions} can be set among
-#'    values 'read', 'update', 'create', 'delete', 'read-write', 'share', 'all'. By default the permissions will 
-#'    be the default permissions set by the ocs server (by default 'all').
-#'  }
-#'  \item{\code{shareWithUser(path, name, username, permissions, pretty)}}{
-#'   Shares a resource (file or folder) with a user given its username handled with argument \code{username}. 
-#'   The \code{permissions} can be set among values 'read', 'update', 'create', 'delete', 'read-write', 'share', 
-#'   'all'. By default the permissions will be the default permissions set by the ocs server (by default 'all').
-#'   Returns the share properties as \code{list} (or as\code{data.frame} if \code{pretty} is set to TRUE).
-#'  }
-#'  \item{\code{shareWithGroup(path, name, group, permissions, pretty)}}{
-#'   Shares a resource (file or folder) with a group given its name handled with argument \code{group}. 
-#'   The \code{permissions} can be set among values 'read', 'update', 'create', 'delete', 'read-write', 'share', 
-#'   'all'. By default the permissions will be the default permissions set by the ocs server (by default 'all').
-#'   Returns the share properties as \code{list} (or as\code{data.frame} if \code{pretty} is set to TRUE).
-#'  }
-#'  \item{\code{shareAsPublicLink(path, name, publicUpload, password, permissions, expireDate)}}{
-#'   Shares a resource (file or folder) as public link. The function returns the public link generated by ocs.
-#'  }
-#'}
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ocsManager for the Sharing API
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -64,15 +11,29 @@ ocsApiSharingManager <-  R6Class("ocsApiSharingManager",
   inherit = ocsManager,
   public = list(
     
+    #'@description Initialize manager
+    #'@param url url
+    #'@param user user
+    #'@param pwd pwd
+    #'@param logger logger
+    #'@param keyring_backend backend to use with \pkg{keyring}. Default is \code{NULL}
     initialize = function(url, user, pwd, logger = NULL,
-                          keyring_backend = 'env'){
+                          keyring_backend = NULL){
       super$initialize(url, user, pwd, logger, keyring_backend)
     },
     
     #OCS SHARING API
     #-------------------------------------------------------------------------------------------
     
-    #getShares
+    #'@description Get list of shares as \code{list}. To return as \code{data.frame}, 
+    #'set \code{pretty = TRUE}. The method accepts additional parameters. 
+    #'@param path path
+    #'@param reshares reshares
+    #'@param shared_with_me list only those shared with me?
+    #'@param state state
+    #'@param subfiles subfiles
+    #'@param pretty pretty
+    #'@return the list of shares as \code{list} or \code{data.frame}
     getShares = function(path = NULL, reshares = FALSE, shared_with_me = NULL,
                          state = NULL, subfiles = FALSE, 
                          pretty = FALSE){
@@ -90,7 +51,7 @@ ocsApiSharingManager <-  R6Class("ocsApiSharingManager",
       request <- "ocs/v1.php/apps/files_sharing/api/v1/shares"
       get_req <- ocsRequest$new(
         type = "HTTP_GET", private$url, request,
-        private$user, pwd = private$keyring_backend$get(service = private$keyring_service, username = paste0(private$user,"_pwd")), 
+        private$user, pwd = private$getPassword(), 
         token = private$getToken(), cookies = private$cookies,
         namedParams = list(
           path = path,
@@ -111,7 +72,19 @@ ocsApiSharingManager <-  R6Class("ocsApiSharingManager",
       return(get_out)
     },
     
-    #createShare
+    #'@description Creates a share for the path (file or folder), given a name. The \code{shareType} should be among
+    #'    values 'user','group','publiclink' or 'federated'.The \code{shareWith} is required for \code{shareType} 
+    #'    'user' and 'group' and corresponds to the username or groupname. The \code{permissions} can be set among
+    #'    values 'read', 'update', 'create', 'delete', 'read-write', 'share', 'all'. By default the permissions will 
+    #'    be the default permissions set by the ocs server (by default 'all').
+    #'@param path path
+    #'@param name name
+    #'@param shareType the type of share
+    #'@param shareWith a list of users to share with
+    #'@param publicUpload public upload
+    #'@param password to set to access the share
+    #'@param permissions permissions
+    #'@param expireDate expire date
     createShare = function(path, name, shareType, shareWith, publicUpload = NULL, password = NULL, 
                            permissions = NULL, expireDate = NULL){
       
@@ -180,7 +153,7 @@ ocsApiSharingManager <-  R6Class("ocsApiSharingManager",
       request <- "ocs/v1.php/apps/files_sharing/api/v1/shares"
       post_req <- ocsRequest$new(
         type = "HTTP_POST", private$url, request,
-        private$user, pwd = private$keyring_backend$get(service = private$keyring_service, username = paste0(private$user,"_pwd")), 
+        private$user, pwd = private$getPassword(), 
         token = private$getToken(), cookies = private$cookies,
         namedParams = list(
           name = name,
@@ -198,7 +171,17 @@ ocsApiSharingManager <-  R6Class("ocsApiSharingManager",
       return(post_req$getResponse())
     },
     
-    #shareWithUser
+    #'@description Shares a resource (file or folder) with a user given its username handled with argument \code{username}. 
+    #'   The \code{permissions} can be set among values 'read', 'update', 'create', 'delete', 'read-write', 'share', 
+    #'   'all'. By default the permissions will be the default permissions set by the ocs server (by default 'all').
+    #'   Returns 
+    #'@param path path
+    #'@param name name
+    #'@param username username
+    #'@param group group
+    #'@param permissions permissions
+    #'@param pretty pretty
+    #'@return the share properties as \code{list} (or as\code{data.frame} if \code{pretty} is set to TRUE).
     shareWithUser = function(path, name, username, permissions = NULL, pretty = FALSE){
       share_resp <- self$createShare(
         path = path,
@@ -214,7 +197,15 @@ ocsApiSharingManager <-  R6Class("ocsApiSharingManager",
       return(share_out)
     },
     
-    #shareWithGroup
+    #'@description Shares a resource (file or folder) with a group given its name handled with argument \code{group}. 
+    #'   The \code{permissions} can be set among values 'read', 'update', 'create', 'delete', 'read-write', 'share', 
+    #'   'all'. By default the permissions will be the default permissions set by the ocs server (by default 'all').
+    #'@param path path
+    #'@param name name
+    #'@param group group
+    #'@param permissions permissions
+    #'@param pretty pretty
+    #'@return the share properties as \code{list} (or as\code{data.frame} if \code{pretty} is set to TRUE).
     shareWithGroup = function(path, name, group, permissions = NULL, pretty = FALSE){
       share_resp <- self$createShare(
         path = path,
@@ -230,7 +221,14 @@ ocsApiSharingManager <-  R6Class("ocsApiSharingManager",
       return(share_out)
     },
     
-    #shareAsPublicLink
+    #'@description Shares a resource (file or folder) as public link. The function returns the public link generated by ocs.
+    #'@param path path
+    #'@param name name
+    #'@param publicUpload public upload?
+    #'@param password password
+    #'@param permissions permissions
+    #'@param expireDate expire date
+    #'@param return the public sharing link
     shareAsPublicLink = function(path, name = NULL, publicUpload = FALSE, password = NULL, 
                                  permissions = NULL, expireDate = NULL){
       if(!private$capabilities$files_sharing$public$enabled){
